@@ -19,9 +19,10 @@ class TextGL(GLDrawable):
         self.vertices = np.empty(3)
 
         self.text = kwargs.get('text', ' ')
-        self.scale = kwargs.get('scale', 0.1)
+        self.scale = kwargs.get('scale', 1.0)
         self.position = kwargs.get('position', [0.0, 0.0, 0.0])
         self.orientation = kwargs.get('orientation', 'elevation')
+        self.centered = kwargs.get('centered', False)
 
     def initialize(self) -> None:
         if self.is_initialized:
@@ -37,6 +38,10 @@ class TextGL(GLDrawable):
         # Now we can update the real vertices
         self.vertices = np.unique(np.array(self.text_vertices).flatten().reshape((-1, 3)), axis=0)
 
+    @property
+    def tex_scale(self) -> float:
+        return self.scale / 48
+
     @staticmethod
     def _rendering_buffer(xpos, ypos, zpos) -> np.ndarray:
         return np.asarray(4 * [xpos, ypos, zpos], np.float32)
@@ -86,21 +91,28 @@ class TextGL(GLDrawable):
         for c in self.text:
             ch = TextProgram.characters[c]
             w, h = ch.textureSize
-            w = w * self.scale
-            h = h * self.scale
+            w = w * self.tex_scale
+            h = h * self.tex_scale
 
             # Select best vertices using orientation
             if self.orientation == 'elevation':
                 self.text_vertices.append(self._rendering_buffer_elevation(x, y, z, w, h))
-                x += (ch.advance >> 6) * self.scale
+                x += (ch.advance >> 6) * self.tex_scale
 
             elif self.orientation == 'north':
                 self.text_vertices.append(self._rendering_buffer_north(x, y, z, w, h))
-                y += (ch.advance >> 6) * self.scale
+                y += (ch.advance >> 6) * self.tex_scale
 
             else:  # if self.orientation == 'east':
                 self.text_vertices.append(self._rendering_buffer_east(x, y, z, w, h))
-                x += (ch.advance >> 6) * self.scale
+                x += (ch.advance >> 6) * self.tex_scale
+
+        # Centered = Position represents center of the whole text, instead of the bottom left.
+        if self.centered:
+            tvs = np.array(self.text_vertices).reshape((-1, 3))
+            ptp = np.ptp(tvs, axis=0)
+            tvs -= ptp / 2
+            self.text_vertices = tvs.reshape((len(self.text), -1))
 
     def generate_buffers(self) -> None:
         self._vaos = [glGenVertexArrays(1)]
