@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 
-#  Copyright (c) 2019-2020 Gabriel Sanhueza.
+#  Copyright (c) 2019-2021 Gabriel Sanhueza.
 #
 #  Distributed under the MIT License.
 #  See LICENSE for more info.
@@ -31,7 +31,6 @@ class MainWindow(QMainWindow):
     def __init__(self, parent=None):
         QMainWindow.__init__(self, parent)
         uic.loadUi(f'{pathlib.Path(__file__).parent}/UI/mainwindow.ui', self)
-        self.resize(1100, 620)
 
         self.setWindowTitle('BlastSightDM')
         self.setWindowIcon(IconCollection.get('blastsight.png'))
@@ -156,7 +155,6 @@ class MainWindow(QMainWindow):
         self.menu_View.addSeparator()
         self.menu_View.addAction(actions.action_grid)
         self.menu_View.addAction(actions.action_take_screenshot)
-        self.menu_View.addAction(actions.action_fix_wobbling)
 
         # Tools
         self.menu_Tools.addAction(actions.action_slice_meshes)
@@ -186,6 +184,8 @@ class MainWindow(QMainWindow):
         self.toolbar.connect_tree(self.dockWidget_tree)
         self.toolbar.connect_camera(self.dockWidget_camera)
         self.toolbar.connect_xsection(self.xsection_widget)
+        self.toolbar.connect_grid(self.grid_widget)
+
         self.cameraWidget.connect_viewer(self.viewer)
         self.treeWidget.connect_viewer(self.viewer)
         self.treeWidget.enable_exportability(True)
@@ -206,9 +206,7 @@ class MainWindow(QMainWindow):
         actions.action_quit.triggered.connect(self.close)
 
         # View
-        actions.action_grid.triggered.connect(self.slot_grid)
         actions.action_take_screenshot.triggered.connect(self.slot_screenshot)
-        actions.action_fix_wobbling.triggered.connect(self.slot_wobbling)
 
         # Tools
         actions.action_slice_meshes.triggered.connect(self.slot_slice_meshes)
@@ -460,10 +458,6 @@ class MainWindow(QMainWindow):
     """
     Slot for extra items in view
     """
-    def slot_grid(self) -> None:
-        # FIXME We can put this in the toolbar too!
-        self.grid_widget.show()
-
     def slot_screenshot(self) -> None:
         (path, selected_filter) = QFileDialog.getSaveFileName(
             parent=self.viewer,
@@ -472,9 +466,6 @@ class MainWindow(QMainWindow):
 
         self.viewer.take_screenshot(path)
 
-    def slot_wobbling(self) -> None:
-        self.viewer.fix_wobbling()
-
     """
     Slots for loading files
     """
