@@ -122,7 +122,6 @@ class IntegrableViewer(QOpenGLWidget):
         self.is_phantom_enabled = False
 
         # Extra information
-        self.is_gl_initialized = False
         self.is_animated = False
         self.fov = 45.0
         self.smoothness = 2.0  # Bigger => smoother (but slower) rotations
@@ -136,6 +135,8 @@ class IntegrableViewer(QOpenGLWidget):
         self.register_drawable(self.factory.background(id=0), self.pre_collection)
         self.register_drawable(self.factory.axis(id=1), self.post_collection)
         self.register_drawable(self.factory.grid(id=2, visible=False), self.post_collection)
+        self.register_drawable(self.factory.lines(id=0, vertices=np.zeros((2, 3)), color=[1.0, 0.8, 0.0],
+                                                  visible=False), self.post_collection)
 
         # Signals
         self.signal_file_modified.connect(self.recreate)
@@ -162,18 +163,61 @@ class IntegrableViewer(QOpenGLWidget):
         glEnable(GL_POINT_SPRITE)
         glDisable(GL_CULL_FACE)
         glEnable(GL_DEPTH_TEST)
-        glBlendFunc(GL_SRC_ALPHA, GL_ONE_MINUS_SRC_ALPHA)
 
         # Initialize collections
         self.pre_collection.initialize()
         self.drawable_collection.initialize()
         self.post_collection.initialize()
-        self.is_gl_initialized = True
 
     def paintGL(self) -> None:
         # Clear screen
         glClear(GL_COLOR_BUFFER_BIT | GL_DEPTH_BUFFER_BIT)
 
+        # Propagate uniform values (matrices, viewport, etc)
+        self.propagate_uniforms()
+
+        # Draw every GLDrawable (meshes, blocks, points, etc)
+        glEnable(GL_BLEND)
+        glBlendFunc(GL_SRC_ALPHA, GL_ONE_MINUS_SRC_ALPHA)
+
+        self.pre_collection.draw()
+        self.drawable_collection.draw()
+        self.post_collection.draw()
+
+        # Tick FPS counter
+        self.fps_counter.tick()
+
+    def resizeGL(self, w: float, h: float) -> None:
+        aspect = w / h
+        max_distance = 100000.0
+
+        if self.current_projection == 'Perspective':
+            self.proj_matrix.perspective(self.fov, aspect, 1.0, max_distance)
+        else:  # if self.current_projection == 'Orthographic':
+            z = self.off_center[2]
+            self.proj_matrix.ortho(-z, z, -z / self.aspect, z / aspect, -max_distance, max_distance)
+
+    @staticmethod
+    def setup_model_matrix(matrix: QMatrix4x4, rotation: np.ndarray, translation: np.ndarray) -> None:
+        matrix.setToIdentity()
+
+        # Translate matrix (translation = rotation_center)
+        matrix.translate(*translation)
+
+        # Rotate matrix
+        matrix.rotate(rotation[0], 1.0, 0.0, 0.0)
+        matrix.rotate(rotation[1], 0.0, 1.0, 0.0)
+        matrix.rotate(rotation[2], 0.0, 0.0, 1.0)
+
+        # Restore matrix
+        matrix.translate(*-translation)
+
+    @staticmethod
+    def setup_view_matrix(matrix: QMatrix4x4, camera: iter) -> None:
+        matrix.setToIdentity()
+        matrix.translate(*-camera)
+
+    def propagate_uniforms(self) -> None:
         # Setup matrices
         self.setup_model_matrix(self.model_matrix, self.rotation_angle, self.render_rotation_center)
         self.setup_view_matrix(self.view_matrix, self.render_camera_position)
@@ -198,44 +242,6 @@ class IntegrableViewer(QOpenGLWidget):
             collection.update_uniform('plane_origin', *self.last_cross_origin)
             collection.update_uniform('plane_normal', *self.last_cross_normal)
 
-        # Draw every GLDrawable (meshes, blocks, points, etc)
-        glEnable(GL_BLEND)
-        self.pre_collection.draw()
-        self.drawable_collection.draw()
-        self.post_collection.draw()
-
-        # Tick FPS counter
-        self.fps_counter.tick()
-
-    def resizeGL(self, w: float, h: float) -> None:
-        aspect = w / h
-
-        if self.current_projection == 'Perspective':
-            self.proj_matrix.perspective(self.fov, aspect, 1.0, 100000.0)
-        else:  # if self.current_projection == 'Orthographic':
-            z = self.off_center[2]
-            self.proj_matrix.ortho(-z, z, -z / self.aspect, z / aspect, 0.0, 100000.0)
-
-    @staticmethod
-    def setup_model_matrix(matrix: QMatrix4x4, rotation: np.ndarray, translation: np.ndarray) -> None:
-        matrix.setToIdentity()
-
-        # Translate matrix (translation = rotation_center)
-        matrix.translate(*translation)
-
-        # Rotate matrix
-        matrix.rotate(rotation[0], 1.0, 0.0, 0.0)
-        matrix.rotate(rotation[1], 0.0, 1.0, 0.0)
-        matrix.rotate(rotation[2], 0.0, 0.0, 1.0)
-
-        # Restore matrix
-        matrix.translate(*-translation)
-
-    @staticmethod
-    def setup_view_matrix(matrix: QMatrix4x4, camera: iter) -> None:
-        matrix.setToIdentity()
-        matrix.translate(*-camera)
-
     """
     Environment drawables
     """
@@ -251,6 +257,10 @@ class IntegrableViewer(QOpenGLWidget):
     def grid(self) -> GLDrawable:
         return self.post_collection.get(2)
 
+    @property
+    def flatline(self) -> GLDrawable:
+        return self.post_collection.get(0)
+
     """
     Properties
     """
